@@ -8,7 +8,7 @@ use overload
   fallback => 1;
 
 # ABSTRACT: Response class for asynchronous ftp client
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 
 sub new
@@ -51,7 +51,7 @@ AnyEvent::FTP::Response - Response class for asynchronous ftp client
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 DESCRIPTION
 
@@ -59,7 +59,9 @@ Instances of this class represent a FTP server response.
 
 =head1 ATTRIBUTES
 
-=head2 $client-E<gt>code
+=head2 code
+
+ my $code = $client->code;
 
 Integer code for the message.  These can be categorized thus:
 
@@ -91,22 +93,31 @@ Generally C<4xx> and C<5xx> messages are errors, where as C<1xx>, C<3xx> are var
 (at least so far) successful operations.  C<2xx> indicates a completely successful
 operation.
 
-=head2 $res-E<gt>message
+=head2 message
+
+ my $message = $res->message;
 
 The human readable message returned from the server.  This is always a list reference,
 even if the server only returned one line.
 
 =head1 METHODS
 
-=head2 $res-E<gt>is_success
+=head2 is_success
+
+ my $bool = $res->is_success;
 
 True if the response does not represent an error condition (codes C<1xx>, C<2xx> or C<3xx>).
 
-=head2 $res-E<gt>is_preliminary
+=head2 is_preliminary
+
+ my $bool = $res->is_preliminary;
 
 True if the response is a preliminary positive reply (code C<1xx>).
 
-=head2 $res-E<gt>as_string
+=head2 as_string
+
+ my $str = $res->as_string;
+ my $str = "$res";
 
 Returns a string representation of the response.  This may not be exactly what was
 returned by the server, but will include the code and at least part of the message in
